[![Build Status](https://git-r3lab.uni.lu/sascha.herzinger/fractalis/badges/master/build.svg)](https://git-r3lab.uni.lu/sascha.herzinger/fractalis/builds/)
[![Coverage Report](https://git-r3lab.uni.lu/sascha.herzinger/fractalis/badges/master/coverage.svg)](https://git-r3lab.uni.lu/sascha.herzinger/fractalis/builds/)

There is no official documentation for deploying Fractalis, **yet**.
Running it in a development environment is very simple, though.
Just have a look at *.gitlab-ci.yml* which demonstrates the setup for a vanilla CentOS installation.